@@ -11,7 +11,7 @@
 extern Communicator * glob_communicator;
 
 
-char * special_names[]={
+const char * special_names[]={
   "@integer",       // 1
   "@string",        // 2
   "@list",          // 3
@@ -45,7 +45,7 @@ char * special_names[]={
 int special_num=29;
 
 
-char * modifier_names[]={
+const char * modifier_names[]={
   ":tabbed",        // 1
   ":framed",        // 2
   ":horizontal",    // 4
@@ -202,9 +202,11 @@ void Grammar::verify_recursion()
 
   int i=0;
   int N=broker.get_nt_num();
-  list<int> is_on_right[N];
+  vector<list<int> > is_on_right;
+  is_on_right.resize(N);
   int validnum=0;
-  bool valid[N];
+  vector<bool> valid;
+  valid.resize(N);
   for (i=0; i<N; i++) valid[i]=false;
 
   list<Rule *>::iterator rp;
