@@ -15,6 +15,8 @@
 #include <iostream>
 #include <sstream>
 #include <string>
+#include <iterator>
+#include <cassert>
 
 #define BORDER 10
 #define SPACING 5
@@ -93,7 +95,7 @@ void button_label(QPushButton * push_button, string s)
 
 Kaptain::Kaptain(Intermediate * i, Kaptain * p,
                  QWidget * widget, QBoxLayout * layout, QDialog * dialog,
-                 bool _no_title, const char *name )
+                 bool _no_title, const char *)
 {
   im=i;
   assert(im!=0);
